@@ -63,10 +63,10 @@ class GSPeerConnectionWatcher:
                     await self.peerConnections.close()
 
             @self.peerConnections.on("track")
-            def on_track(track):
+            async def on_track(track):
                 if track.kind == "video":
                     if self.ontrack is not None:
-                        self.ontrack(self.gsdbs, track)
+                        await self.ontrack(self.gsdbs, track)
 
                 @track.on("ended")
                 async def on_ended():
